pub struct ReactionEvent {
pub thread_id: String,
pub message_id: String,
pub user: Author,
pub emoji: EmojiValue,
pub added: bool,
pub adapter_name: String,
}Expand description
A reaction was added to or removed from a message.
Fields
thread_id: StringThread containing the reacted message.
message_id: StringThe message that was reacted to.
user: AuthorThe user who added or removed the reaction.
emoji: EmojiValueThe emoji used for the reaction.
added: booltrue when the reaction was added, false when removed.
adapter_name: StringName of the adapter that delivered this event.