Module message

Module message 

Core message types for the chat channel layer.

Structs

Author
Identifies the author of an incoming message.
EphemeralMessage
An ephemeral (visible-only-to-user) message confirmation.
IncomingMessage
A message received from an external chat platform.
SentMessage
Confirmation returned after a message has been successfully sent.

Enums

AdapterPostableMessage
Adapter-level postable message, extending PostableMessage with attachment support.
PostableMessage
A message that the agent wants to send to a channel.