Core message types for the chat channel layer.
Structs
- Author
- Identifies the author of an incoming message.
- Ephemeral
Message - An ephemeral (visible-only-to-user) message confirmation.
- Incoming
Message - A message received from an external chat platform.
- Sent
Message - Confirmation returned after a message has been successfully sent.
Enums
- Adapter
Postable Message - Adapter-level postable message, extending
PostableMessagewith attachment support. - Postable
Message - A message that the agent wants to send to a channel.